# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.awsHardcodedPassword

Module implementing checks for potentially hardcoded AWS passwords.

### Global Attributes

AWS_ACCESS_KEY_ID_MAX_ENTROPY
AWS_ACCESS_KEY_ID_REGEX
AWS_ACCESS_KEY_ID_SYMBOLS
AWS_SECRET_ACCESS_KEY_MAX_ENTROPY
AWS_SECRET_ACCESS_KEY_REGEX
AWS_SECRET_ACCESS_KEY_SYMBOLS

### Classes

None

### Functions

checkHardcodedAwsKey | Function to check for potentially hardcoded AWS passwords.
getChecks | Public method to get a dictionary with checks handled by this module.
shannonEntropy | Function to caclculate the Shannon entropy of some given data.

## checkHardcodedAwsKey

checkHardcodedAwsKey(reportError, context, _config)

Function to check for potentially hardcoded AWS passwords.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up

## shannonEntropy

shannonEntropy(data, symbols)

Function to caclculate the Shannon entropy of some given data.

Source: http://blog.dkbza.org/2007/05/scanning-data-for-entropy-anomalies.html

data (str)
  data to calculate the entropy for
symbols (str)
  allowed symbols

Return:
  Shannon entropy of the given data

Return Type:
  float

Up